@@ -7,6 +7,8 @@ from pyqtgraph import debug as debug
 from collections.abc import Callable
 from pytplot import tplot_opt_glob
 import pandas as pd
+from ..CustomViewBox.NoPaddingPlot import NoPaddingPlot
+
 
 class UpdatingImage(pg.ImageItem):
     '''
@@ -55,8 +57,9 @@ class UpdatingImage(pg.ImageItem):
             minbin = ymin
             maxbin = ymax
 
+            # This will be the values of the 100 y axis pixels
             if ytype == 'log':
-                yp = np.logspace(np.log10(minbin), np.log10(maxbin), 100)
+                yp = np.linspace(np.log10(minbin), np.log10(maxbin), 100)
             else:
                 yp = np.linspace(minbin, maxbin, 100)
 
@@ -65,6 +68,8 @@ class UpdatingImage(pg.ImageItem):
             prev_bins = self.bin_sizes.iloc[0]
             prev_closest_ys = np.searchsorted(self.bin_sizes.iloc[0], yp, sorter=y_sort)
             prev_closest_ys[prev_closest_ys > (len(self.bin_sizes.iloc[0]) - 1)] = len(self.bin_sizes.iloc[0]) - 1
+
+            # Loop through every X value and inspect the spec_bins.
             for i in closest_xs:
                 if (self.bin_sizes.iloc[i] == prev_bins).all():
                     closest_ys = prev_closest_ys
@@ -84,7 +89,10 @@ class UpdatingImage(pg.ImageItem):
             data_reformatted = pd.DataFrame(data_reformatted)
 
             self.x = xp
-            self.y = np.linspace(np.log10(minbin), np.log10(maxbin), 100)
+            if ytype == 'log':
+                self.y = np.linspace(np.log10(minbin), np.log10(maxbin), 100)
+            else:
+                self.y = np.linspace(minbin, maxbin, 100)
             self.data = data_reformatted
         else:
             if ytype == 'log':
@@ -166,11 +174,15 @@ class UpdatingImage(pg.ImageItem):
         I have no idea why, but we need to generate the picture after painting otherwise 
         it draws incorrectly.  
         '''
+        parents = self.getBoundingParents()
+        for x in parents:
+            if type(x) is NoPaddingPlot:
+                parent_viewbox = x
         if self.picturenotgened:
-            self.generatePicture(self.getBoundingParents()[0].rect())
+            self.generatePicture(parent_viewbox.rect())
             self.picturenotgened = False
         pg.ImageItem.paint(self, p, *args)
-        self.generatePicture(self.getBoundingParents()[0].rect())
+        self.generatePicture(parent_viewbox.rect())
 
     def render(self):
         #The same as pyqtgraph's ImageItem.render, with the exception that the makeARGB function is slightly different
